# Generated by Django 4.2.15 on 2024-08-28 11:05

import django.core.files.storage
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0001_initial'),
    ]

    operations = [
        migrations.CreateModel(
            name='AnonymizedImageLabel',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255, unique=True)),
                ('description', models.TextField(blank=True, null=True)),
            ],
        ),
        migrations.CreateModel(
            name='AnonymousImageAnnotation',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('image_name', models.CharField(max_length=255)),
                ('slug', models.SlugField(blank=True, null=True, unique=True)),
                ('polyp_count', models.IntegerField()),
                ('comments', models.CharField(max_length=255)),
                ('gender', models.CharField(max_length=255)),
                ('name_image_url', models.CharField(max_length=255)),
                ('date_created', models.DateTimeField(auto_now_add=True)),
                ('label', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.label')),
            ],
        ),
        migrations.AlterField(
            model_name='rawpdffile',
            name='file',
            field=models.FileField(storage=django.core.files.storage.FileSystemStorage(location='/home/agl-admin/agl-validator-backend/agl_validator_backend/erc_data/raw_pdf'), upload_to='raw_pdf/', validators=[django.core.validators.FileExtensionValidator(allowed_extensions=['pdf'])]),
        ),
        migrations.CreateModel(
            name='DroppedName',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name', models.CharField(max_length=255)),
                ('gender', models.CharField(max_length=255)),
                ('x', models.FloatField()),
                ('y', models.FloatField()),
                ('name_image_url', models.CharField(max_length=255)),
                ('annotation', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, related_name='dropped_names', to='endoreg_db.anonymousimageannotation')),
            ],
        ),
    ]



# Generated by Django 4.2.14 on 2024-09-04 19:48

import django.core.files.storage
import django.core.validators
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0003_anonymousimageannotation_original_image_url_and_more'),
    ]

    operations = [
        migrations.AlterField(
            model_name='rawpdffile',
            name='file',
            field=models.FileField(storage=django.core.files.storage.FileSystemStorage(location='/home/agl-admin/agl_anonymizer/agl_anonymizer/erc_data/raw_pdf'), upload_to='raw_pdf/', validators=[django.core.validators.FileExtensionValidator(allowed_extensions=['pdf'])]),
        ),
    ]



# Generated by Django 4.2.15 on 2024-09-17 11:46

import django.core.files.storage
import django.core.validators
from django.db import migrations, models
import django.db.models.deletion
import django.utils.timezone


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0004_alter_rawpdffile_file'),
    ]

    operations = [
        migrations.CreateModel(
            name='UploadedFile',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('original_file', models.FileField(upload_to='uploads/original/')),
                ('upload_date', models.DateTimeField(default=django.utils.timezone.now)),
                ('description', models.TextField(blank=True, null=True)),
            ],
        ),
        migrations.AlterField(
            model_name='rawpdffile',
            name='file',
            field=models.FileField(storage=django.core.files.storage.FileSystemStorage(location='/mnt/hdd-sensitive/Pseudo/import/pdf'), upload_to='raw_pdf/', validators=[django.core.validators.FileExtensionValidator(allowed_extensions=['pdf'])]),
        ),
        migrations.CreateModel(
            name='AnonymizedFile',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('anonymized_file', models.FileField(upload_to='uploads/anonymized/')),
                ('anonymization_date', models.DateTimeField(default=django.utils.timezone.now)),
                ('original_file', models.OneToOneField(on_delete=django.db.models.deletion.CASCADE, related_name='anonymized_file', to='endoreg_db.uploadedfile')),
            ],
        ),
    ]



# Generated by Django 4.2.15 on 2024-08-29 07:15

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('endoreg_db', '0002_anonymizedimagelabel_anonymousimageannotation_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='anonymousimageannotation',
            name='original_image_url',
            field=models.CharField(default='https://example.com/placeholder.jpg', max_length=255),
        ),
        migrations.AddField(
            model_name='anonymousimageannotation',
            name='processed',
            field=models.BooleanField(default=False),
        ),
        migrations.AddField(
            model_name='droppedname',
            name='box_coordinates',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
        migrations.AlterField(
            model_name='anonymousimageannotation',
            name='comments',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='anonymousimageannotation',
            name='label',
            field=models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='endoreg_db.anonymizedimagelabel'),
        ),
    ]



from django.db import models
from django.utils.text import slugify

class AnonymizedImageLabel(models.Model):
    name = models.CharField(max_length=255, unique=True)  # Ensuring label names are unique
    description = models.TextField(blank=True, null=True)  # Optional description field

    def __str__(self):
        return self.name

class AnonymousImageAnnotation(models.Model):
    label = models.ForeignKey(AnonymizedImageLabel, on_delete=models.CASCADE)
    image_name = models.CharField(max_length=255)
    original_image_url = models.CharField(max_length=255, default='https://example.com/placeholder.jpg') # Field for the original image
    slug = models.SlugField(unique=True, blank=True, null=True)
    polyp_count = models.IntegerField()
    comments = models.TextField(blank=True, null=True)  # Comments can be longer
    gender = models.CharField(max_length=255)  # Overall gender (if applicable)
    name_image_url = models.CharField(max_length=255)
    date_created = models.DateTimeField(auto_now_add=True)
    processed = models.BooleanField(default=False)  # Track if this annotation has been processed

    def save(self, *args, **kwargs):
        if not self.slug:
            self.slug = slugify(f"{self.label}-{self.image_name}")
        super().save(*args, **kwargs)

    def __str__(self):
        return f"{self.image_name} - {self.label}"

class DroppedName(models.Model):
    annotation = models.ForeignKey(AnonymousImageAnnotation, related_name='dropped_names', on_delete=models.CASCADE)
    name = models.CharField(max_length=255)
    gender = models.CharField(max_length=255)  # Gender of the individual name
    x = models.FloatField()
    y = models.FloatField()
    name_image_url = models.CharField(max_length=255)
    box_coordinates = models.CharField(max_length=255, blank=True, null=True)  # Store box coordinates if needed

    def __str__(self):
        return f"{self.name} ({self.gender}) at ({self.x}, {self.y})"

from django.db import models
from django.utils import timezone

class UploadedFile(models.Model):
    original_file = models.FileField(upload_to='uploads/original/')
    upload_date = models.DateTimeField(default=timezone.now)
    description = models.TextField(blank=True, null=True)
    
    def __str__(self):
        return self.original_file.name
    
class AnonymizedFile(models.Model):
    original_file = models.OneToOneField(UploadedFile, on_delete=models.CASCADE, related_name='anonymized_file')
    anonymized_file = models.FileField(upload_to='uploads/anonymized/')
    anonymization_date = models.DateTimeField(default=timezone.now)
    
    def __str__(self):
        return f"Anonymized version of {self.original_file.original_file.name}"



from .image_classification import ImageClassificationAnnotation
from .binary_classification_annotation_task import LegacyBinaryClassificationAnnotationTask, BinaryClassificationAnnotationTask
from .anonymized_image_annotation import AnonymousImageAnnotation, DroppedName, AnonymizedImageLabel, AnonymizedFile, UploadedFile
